# Python Liquid Babel

Internationalization and localization for [Liquid](https://github.com/jg-rp/liquid/) templates.

[![PyPI](https://img.shields.io/pypi/v/liquid-babel?style=flat-square)](https://pypi.org/project/liquid-babel/)
[![GitHub Workflow Status](https://img.shields.io/github/workflow/status/jg-rp/liquid-babel/Tests?style=flat-square)](https://github.com/jg-rp/liquid-babel/actions)
[![PyPI - License](https://img.shields.io/pypi/l/liquid-babel?style=flat-square)](https://github.com/jg-rp/liquid-babel/blob/main/LICENSE)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/liquid-babel?style=flat-square)](https://pypi.org/project/liquid-babel/)
![PyPy Version](https://img.shields.io/badge/pypy-3.7%20%7C%203.8%20%7C%203.9-blue?style=flat-square)

## Install

Install Python Liquid Babel using [pipenv](https://pipenv.pypa.io/en/latest/):

```plain
$ pipenv install liquid-babel
```

Or [pip](https://pip.pypa.io/en/stable/getting-started/):

```plain
$ python -m pip install -U liquid-babel
```

## Links

- Documentation: https://jg-rp.github.io/liquid/babel/introduction
- Filter reference: https://jg-rp.github.io/liquid/babel/filters
- Change log: https://github.com/jg-rp/liquid-babel/blob/main/CHANGES.md
- PyPi: https://pypi.org/project/liquid-babel/
- Source Code: https://github.com/jg-rp/liquid-babel
- Issue tracker: https://github.com/jg-rp/liquid-babel/issues
